Steno3D
*******

.. image:: https://travis-ci.org/3ptscience/steno3dpy.svg?branch=master
    :target: https://travis-ci.org/3ptscience/steno3dpy

Welcome to the Python client library for `Steno3D <https://www.steno3d.com>`_
by `3point Science <https://www.3ptscience.com>`_.

If you have not yet installed Steno3d, all you need to do is

.. code:: bash

    pip install steno3d

You also need to `sign up for a Steno3D account <https://www.steno3d.com/signup>`_.
From there, you can `request a developer API key <https://www.steno3d.com/settings/developer>`_.

At that point, you can

.. code:: python

    import steno3d
    steno3d.login()

then start building your 3D project. API documentation is available on
`Read the Docs <http://steno3d.readthedocs.io/en/latest>`_. Tutorials and
Examples are available as `notebooks <http://mybinder.org/3ptscience/steno3dpy>`_.
Steno3D is built with tab-completion in mind for interactive environments like
the Jupyter Notebook. Class documentation can also be accessed in the python environment
with `?` and tab completion.
